"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fast_components_react_base_1 = require("@microsoft/fast-components-react-base");
const fast_components_react_msft_1 = require("@microsoft/fast-components-react-msft");
const rule_1 = __importDefault(require("./rule"));
var ComponentType;
(function (ComponentType) {
    ComponentType["heading"] = "heading";
    ComponentType["hyperlink"] = "hyperlink";
    ComponentType["list"] = "list";
    ComponentType["paragraph"] = "paragraph";
})(ComponentType || (ComponentType = {}));
class FastMarkdownIt {
    constructor(md) {
        /**
         * Due to special characters such as {, }, < and > being interpreted by React
         * as meaningful characters, these are replaced with the HTML code versions
         */
        this.replaceSpecialCharacters = (content) => {
            return content
                .replace(/{/g, "&#123;")
                .replace(/}/g, "&#125;")
                .replace(/</g, "&#60;")
                .replace(/>/g, "&#62;");
        };
        md.core.ruler.push("fast", new rule_1.default(md));
        md.renderer.rules.paragraph_open = function () {
            return `<Typography size={${fast_components_react_base_1.TypographySize._7}}>`;
        };
        md.renderer.rules.heading_open = function (tokens, idx) {
            const id = tokens[idx + 1].children[0].content
                .toLowerCase()
                .replace(/\s/g, "-")
                .replace(/[^a-z\-]/g, "");
            return `<Heading id="${id}" tag="${fast_components_react_msft_1.HeadingTag[tokens[idx].tag]}" size={${fast_components_react_msft_1.HeadingSize["_" + (parseInt(tokens[idx].tag.charAt(1), 10) + 2).toString()]}}>`;
        };
        md.renderer.rules.text = (tokens, idx) => {
            return this.replaceSpecialCharacters(tokens[idx].content);
        };
        md.renderer.rules.fence = function (tokens, idx) {
            let codeSnippet = `<pre${tokens[idx].info ? ` className="language-${tokens[idx].info}"` : ""}><code>`;
            codeSnippet += `{${JSON.stringify(tokens[idx].content, null, 2)}}`;
            codeSnippet += `</code></pre>`;
            return codeSnippet;
        };
    }
}
function plugin(md) {
    const fastMarkdownIt = new FastMarkdownIt(md);
}
exports.default = plugin;
